@@ -46,6 +46,9 @@ class Dupamb:
             f.write(diction[i]+i.rstrip().replace(" ",",")+"\n")
         f.close()
 import sys
-filename = sys.argv[1]
-obj = Dupamb(filename)
-obj.removeDupAmb()
\ No newline at end of file
+def main():
+    filename = sys.argv[1]
+    obj = Dupamb(filename)
+    obj.removeDupAmb()
+if __name__=="__main__":
+    main()
\ No newline at end of file
